<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://brewpixel.com
 * @since      1.0.0
 *
 * @package    BrewPixel_Development
 * @subpackage BrewPixel_Development/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    BrewPixel_Development
 * @subpackage BrewPixel_Development/admin
 * @author     Martin Goldie <martin@brewpixel.com>
 */
class BrewPixel_Development_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $brewpixel_development    The ID of this plugin.
	 */
	private $brewpixel_development;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $brewpixel_development       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $brewpixel_development, $version ) {

		$this->brewpixel_development = $brewpixel_development;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in BrewPixel_Development_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The BrewPixel_Development_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->brewpixel_development, plugin_dir_url( __FILE__ ) . 'css/brewpixel-development-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in BrewPixel_Development_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The BrewPixel_Development_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->brewpixel_development, plugin_dir_url( __FILE__ ) . 'js/brewpixel-development-admin.js', array( 'jquery' ), $this->version, false );

	}

}
