<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              http://brewpixel.com
 * @since             0.1.0
 * @package           BrewPixel_Development
 *
 * @wordpress-plugin
 * Plugin Name:       BrewPixel Development
 * Plugin URI:        http://brewpixel.com/plugins/brewpixel-development/
 * Description:       Only used in development of website. Outputs hook comments.
 * Version:           0.1.0
 * Author:            BrewPixel, Martin Goldie
 * Author URI:        http://brewpixel.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       brewpixel-development
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-brewpixel-development-activator.php
 */
function activate_brewpixel_development() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-brewpixel-development-activator.php';
	BrewPixel_Development_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-brewpixel-development-deactivator.php
 */
function deactivate_brewpixel_development() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-brewpixel-development-deactivator.php';
	BrewPixel_Development_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_brewpixel_development' );
register_deactivation_hook( __FILE__, 'deactivate_brewpixel_development' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-brewpixel-development.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_brewpixel_development() {

	$plugin = new BrewPixel_Development();
	$plugin->run();

}
run_brewpixel_development();

add_action( 'all', 'bp_show_hooks' );
function bp_show_hooks ( $tag ) {
	global $debug_tags;
	$debug_tags = array();
	if ( in_array( $tag, $debug_tags, true ) ) {
		return;
	}
	// @TODO: Add option for Genesis or not.
	$layout_tags = [
		'genesis_before_header',
		'genesis_header',
		'genesis_site_title',
		'genesis_site_description',
		'genesis_header_right',
		'dynamic_sidebar_before',
		'dynamic_sidebar',
		'dynamic_sidebar_after',
		'genesis_after_header',
		'genesis_before_content_sidebar_wrap',
		'genesis_before_content',
		'genesis_before_loop',
		'genesis_loop',
		'genesis_loop_else',
		'genesis_before_while',
		'loop_start',
		'genesis_before_entry',
		'genesis_entry_header',
		'genesis_before_entry_content',
		'genesis_entry_content',
		'genesis_after_entry_content',
		'genesis_entry_footer',
		'genesis_after_entry',
		'genesis_before_comments',
		'genesis_list_comments',
		'genesis_before_comment',
		'genesis_after_comment',
		'genesis_after_comments',
		'genesis_before_pings',
		'genesis_after_pings',
		'genesis_before_comment_form',
		'genesis_comment_form',
		'comment_form_before',
		'comment_form_top',
		'comment_form_before_fields',
		'comment_form_after_fields',
		'comment_form',
		'comment_form_after',
		'after_comment_form',
		'loop_end',
		'genesis_after_endwhile',
		'genesis_after_loop',
		'genesis_after_content',
		'genesis_after_content_sidebar_wrap',
	];
	if ( has_filter( 'brewpixel_development_show_hooks_list' ) ) {
		$layout_tags = apply_filters( 'brewpixel_development_show_hooks_list', $layout_tags );
	}
	$priorities = [ 1, 10, 999 ];
	if ( has_filter( 'brewpixel_development_priorities' ) ) {
		$priorities = apply_filters( 'brewpixel_development_priorities', $priorities );
	}
	if ( in_array( $tag, $layout_tags, true ) ) {
		foreach ( $priorities as $priority ) {
			add_action( $tag, 'brewpixel_debug_hooks', $priority );
		}
	}
	$debug_tags[] = $tag;
}

/**
 * brewpixel_debug_hooks
 */
function brewpixel_debug_hooks() {
	global $wp_filter;
	$current_priority = $wp_filter[ current_filter() ]->current_priority();
	$debug_output = '<!-- ' . esc_html( current_filter() . ' ' . $current_priority ) . ' -->';
	if ( has_filter( 'brewpixel_development_debug_output' ) ) {
		$debug_output = apply_filters( 'brewpixel_development_debug_output', $debug_output );
	}
	echo wp_kses_post( $debug_output );
}
